import React,{Component} from 'react';
import {AutoComplete, Form, message, Modal, Spin} from "antd";
import ProForm, {ModalForm, ProFormCheckbox, ProFormSelect, ProFormText} from "@ant-design/pro-form";
import {post, roleResources, station,cityArr} from "@/utils/dataDic";
import { LoadingOutlined } from '@ant-design/icons';
import {getSelectSuperId,getRolesList} from "@/services/user";
import ImgOperation from "@/components/common/ImgOperation";
import {selectName} from "@/pages/admin/user/jurisdiction/services/API";
import {getSelectName} from '../services/API';

const { Option } = AutoComplete;

class AddUser extends Component{
  constructor(props) {
    super(props);
    this.state={
      loading: false,
      fileList: [],
      uploadImgLoading: false,
      modules: [],
    }
    this.handleSearchModule= this.handleSearchModule.bind(this);
  }

  addUser= async ()=>{
    if(this.state.uploadImgLoading){
      message.info('有图片正在上传中,请稍后');
      return;
    }
  }

  getStation = async () => {
    station.map((v)=>{
      v.label = v.key;
      return v;
    })
    return station;
  }

  getPost = async () => {
    post.map((v)=>{
      v.label = v.key;
      return v;
    })
    return post;
  }

  getCityArr = async () => {
    cityArr.map((v)=>{
      v.label = v.key;
      return v;
    })
    return cityArr;
  }

  getRolesList=async (value)=>{
    const msg = await getRolesList(value);
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
    }else{
      message.error(msg.error[0].message)
    }
    return theArr;
  }

  departmentList = async() => {
    const msg = await getSelectSuperId();
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
    }else{
      message.info(msg.error[0].message)
    }
    return theArr;
  }

  handleSearchModule=async (value)=>{
    const msg = await getSelectName(value);
    if(msg.error.length === 0){
      this.setState({
        modules: msg.data
      })
    }else{
      message.error(msg.error[0].message)
    }
  }

  formRef = React.createRef();

  render() {
    return (
      <ModalForm
        formRef={this.formRef}
        visible={this.props.visible}
        preserve={false}
        title='新建用户'
        modalProps={{
          onCancel: (e) => {e.stopPropagation();this.props.onCancel();},
        }}
        onFinish={this.addUser}
      >
          <ProForm.Group>
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入用户名'
                }
              ]}
              placeholder="请输入用户名"
              name="mobile"
              label="用户名"
            />
            <ProFormSelect
              width="m"
              rules={[
                {
                  required:true,
                  message:'请选择用户角色'
                }
              ]}
              placeholder="请选择用户角色"
              label='用户角色'
              name="roles"
              request={this.getRolesList}/>
          </ProForm.Group>
          <ProForm.Group>
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入用户姓名'
                }
              ]}
              placeholder="请输入用户姓名"
              name="name"
              label="用户姓名"
            />
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入联系方式'
                },
                {
                  pattern: /^1\d{10}$/,
                  message: '不合法的手机号格式!',
                }
              ]}
              placeholder="请输入手机号"
              name="contactMobile"
              label="联系方式"
            />
          </ProForm.Group>
          <ProForm.Group>
            <ProFormSelect
              width="m"
              rules={[
                {
                  required:true,
                  message:'请选择组织部门'
                }
              ]}
              placeholder="请选择组织部门"
              label='组织部门'
              name="departmentId"
              request={this.departmentList}/>
            <ProFormSelect
              width="m"
              rules={[
                {
                  required:true,
                  message:'请选择职务'
                }
              ]}
              placeholder="请选择职务"
              label='职务'
              name="duty"
              request={this.getPost}/>
          </ProForm.Group>
          <ProForm.Group>
            <ProFormSelect
              width="m"
              rules={[
                {
                  required:true,
                  message:'请选择岗位'
                }
              ]}
              placeholder="请选择岗位"
              label='岗位'
              name="position"
              request={this.getStation}/>
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入电子邮箱'
                },
                {
                  pattern: /^[A-Za-z0-9\-_]+[A-Za-z0-9\.\-_]*[A-Za-z0-9\-_]+@[A-Za-z0-9]+[A-Za-z0-9\.\-_]*(\.[A-Za-z0-9\.\-_]+)*[A-Za-z0-9]+\.[A-Za-z0-9]+[A-Za-z0-9\.\-_]*[A-Za-z0-9]+$/,
                  message: '不合法的邮箱格式!',
                },
              ]}
              placeholder="请输入电子邮箱"
              name="email"
              label="电子邮箱"
            />
          </ProForm.Group>
          <ProForm.Group>
            <Form.Item
              rules={[
                {
                  required:true,
                  message:'请选择上级主管'
                }
              ]}
              label="上级主管"
              name='superior'
            >
              <AutoComplete
                style={{
                  width:'328px'
                }}
                onSearch={this.handleSearchModule}
                placeholder="请输入名称"
              >
                {this.state.modules.map((v) => (
                  <Option key={v.id} value={v.name}>
                    {v.name}
                  </Option>
                ))}
              </AutoComplete>
            </Form.Item>
            <ProFormSelect
              mode="multiple"
              allowClear
              width="m"
              rules={[
                {
                  required:true,
                  message:'请选择地区'
                }
              ]}
              placeholder="请选择地区"
              label='地区'
              name="district"
              request={this.getCityArr}/>
          </ProForm.Group>
          <ProForm.Group>
            <Form.Item label='用户头像'  name="orgCodeUrl" extra="图片建议：要清晰。">
              <ImgOperation
                domId='uploadAdminImg'
                uploadConfig={{
                  action:'/api/admin/superviser/uploadAdminImg',
                  multiple:true,
                  data:{ 'sign': this.props.pictureSign || '' },
                  listType:"picture-card",
                }}
                onChange={(infor)=>{
                  this.setState({
                    fileList: infor.fileList,
                  });
                }}
                fileList={this.state.fileList}
                onUploadState={(v)=>{
                  this.setState({
                    uploadImgLoading: v.state === 'uploading'
                  })
                }}
              />
            </Form.Item>
          </ProForm.Group>
      </ModalForm>
    )
  }
}

export default AddUser;
